.. neurtu documentation master file, created by
   sphinx-quickstart on Mon Feb 19 17:23:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

neurtu
======

Simple performance measurement tool



neurtu is a Python package providing a common interface for multi-metric benchmarks
(including time and memory measurements). It can can be used to estimate time
and space complexity of algorithms, while pandas integration
allows quick analysis and visualization of the results.

Setting the number of threads at runtime in OpenBlas, and MKL is also supported on Linux
and MacOS.

*neurtu* means "to measure / evaluate" in Basque language.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   examples/index
   api
   release-notes.rst



